import { ICreateCalendarDTO } from "@modules/calendar/dtos/ICreateCalendarDTO";
import { Calendar, prisma } from "@prisma/client";
import prismaClient from "@shared/infra/prisma";
import { ICalendarsRepository } from "../ICalendarsRepository";

class CalendarRepository implements ICalendarsRepository {
    async create({ title, information, date }: ICreateCalendarDTO): Promise<Calendar> {
        const calendar = await prismaClient.calendar.create({
            data: {
                title,
                information,
                date
            }
        })

        return calendar
    }

    async findById(id: string): Promise<Calendar> {
        const calendar = await prismaClient.calendar.findUnique({
            where: { id }
        })

        return calendar as Calendar
    }

    async findAllCalendar(): Promise<Calendar[]> {
        const calendars = await prismaClient.calendar.findMany()
        return calendars
    }

    async findByTitle(title: string): Promise<Calendar> {
        const calendar = await prismaClient.calendar.findFirst({
            where: { title }
        })
        return calendar as Calendar
    }

    async deleteCalendar(id: string): Promise<Boolean> {
        await prismaClient.calendar.delete({
            where: { id }
        })

        return true
    }
}

export { CalendarRepository }