
import { ICursersRepository } from "@modules/curses/repositories/ICursersRepository";
import { AppError } from "@shared/error/AppError";
import { inject, injectable } from "tsyringe";

interface IRequest {
    title: string,
    information: string,
}

@injectable()
class CreateCurserUseCase {
    constructor(
        @inject('CursersRepository')
        private cursersRepository: ICursersRepository
    ) {}

    async execute({title, information}: IRequest) {
        const curserAlreadyExists = await this.cursersRepository.findByTitle(title)
        if(curserAlreadyExists) {
            throw new AppError('Curser Already Exists', 400)
        }

        const curser = await this.cursersRepository.create({
            title,
            information
        })

        return curser
    }
}

export {CreateCurserUseCase}